==> dev-plugin-android-0.0.23-sources.jar: com/zoyi/channel/plugin/android/ActivityLifecycleManager.java <==
package com.zoyi.channel.plugin.android;

import android.app.Activity;
import android.app.Application;
import android.os.Bundle;
import com.zoyi.channel.plugin.android.activity.userchat_list.UserChatListActivity;
import com.zoyi.channel.plugin.android.enumerate.Command;
import com.zoyi.channel.plugin.android.event.CommandBus;
import com.zoyi.channel.plugin.android.event.RxBus;
import com.zoyi.channel.plugin.android.socket.SocketManager;
import com.zoyi.channel.plugin.android.util.L;

/**
 * Created by mika on 2016. 12. 21..
 */
public class ActivityLifecycleManager implements Application.ActivityLifecycleCallbacks {
  private int running = 0;

  @Override
  public void onActivityCreated(Activity activity, Bundle savedInstanceState) {
    L.d("onStart: " + activity.getClass().getSimpleName());
    if (activity instanceof UserChatListActivity) {
      ChannelStore.setMainRunning(true);
    }
  }

  @Override
  public void onActivityStarted(Activity activity) {
    L.d("Started: " + activity.getClass().getSimpleName() + " " + running + " -> " + (running + 1));
    if (++running == 1) {
      RxBus.post(new CommandBus(Command.APP_STARTED));
      SocketManager.connect();
    }
  }

  @Override
  public void onActivityResumed(Activity activity) {
  }

  @Override
  public void onActivityPaused(Activity activity) {
  }

  @Override
  public void onActivityStopped(Activity activity) {
    L.d("Stopped: " + activity.getClass().getSimpleName() + " " + running + " -> " + (running - 1));
    if (--running == 0) {
      SocketManager.disconnect();
      RxBus.post(new CommandBus(Command.APP_STOPPED));
    }
  }

  @Override
  public void onActivitySaveInstanceState(Activity activity, Bundle outState) {

  }

  @Override
  public void onActivityDestroyed(Activity activity) {
    L.d("onDestroy: " + activity.getClass().getSimpleName());
    if (activity instanceof UserChatListActivity) {
      ChannelStore.setMainRunning(false);
    }
  }
}

==> dev-plugin-android-0.0.54-sources.jar: com/zoyi/channel/plugin/android/ActivityLifecycleManager.java <==
package com.zoyi.channel.plugin.android;

import android.app.Activity;
import android.app.Application;
import android.os.Bundle;

import com.zoyi.channel.plugin.android.activity.userchat_list.UserChatListActivity;
import com.zoyi.channel.plugin.android.enumerate.Command;
import com.zoyi.channel.plugin.android.event.CommandBus;
import com.zoyi.channel.plugin.android.event.RxBus;
import com.zoyi.channel.plugin.android.global.Const;
import com.zoyi.channel.plugin.android.socket.SocketManager;
import com.zoyi.channel.plugin.android.util.L;

/**
 * Created by mika on 2016. 12. 21..
 */
public class ActivityLifecycleManager implements Application.ActivityLifecycleCallbacks {

  private Activity startedActivity;
  private int running = 0;

  public void finish() {
    if (startedActivity != null) {
      startedActivity.setResult(Const.RESULT_ACTIVITY_FINISH);
      startedActivity.finish();
    }
  }

  @Override
  public void onActivityCreated(Activity activity, Bundle savedInstanceState) {
    L.d("onStart: " + activity.getClass().getSimpleName());
    if (activity instanceof UserChatListActivity) {
      ChannelStore.setMainRunning(true);
    }
  }

  @Override
  public void onActivityStarted(Activity activity) {
    L.d("Started: " + activity.getClass().getSimpleName() + " " + running + " -> " + (running + 1));
    startedActivity = activity;
    if (++running == 1) {
      RxBus.post(new CommandBus(Command.APP_STARTED));
      SocketManager.connect();
    }
  }

  @Override
  public void onActivityResumed(Activity activity) {
  }

  @Override
  public void onActivityPaused(Activity activity) {
  }

  @Override
  public void onActivityStopped(Activity activity) {
    L.d("Stopped: " + activity.getClass().getSimpleName() + " " + running + " -> " + (running - 1));
    if (--running == 0) {
      SocketManager.disconnect();
      RxBus.post(new CommandBus(Command.APP_STOPPED));
    }
  }

  @Override
  public void onActivitySaveInstanceState(Activity activity, Bundle outState) {

  }

  @Override
  public void onActivityDestroyed(Activity activity) {
    L.d("onDestroy: " + activity.getClass().getSimpleName());
    if (activity instanceof UserChatListActivity) {
      ChannelStore.setMainRunning(false);
    }
  }
}
